#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	public class Leader : Indicator
	{
		private Series<double> mySeries1;
		private Series<double> mySeries2;

		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @" Leader Of The MACD as discussed in July 2008 Stocks & Commodities";
				Name										= "Leader";
				Calculate									= Calculate.OnBarClose;
				IsOverlay									= false;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				Fast					= 12;
				Slow					= 26;
				AddPlot(Brushes.Red, "Leaderplot");
			}
			else if (State == State.DataLoaded)
			{				
				mySeries1 = new Series<double>(this);
				mySeries2 = new Series<double>(this);
			}
		}

		protected override void OnBarUpdate()
		{
			mySeries1[0]	=	(Close[0] - EMA(Fast)[0]);
			mySeries2[0]	=	(Close[0] - EMA(Slow)[0]);
            Leaderplot[0]	=	((EMA(Fast)[0] + EMA(mySeries1, Fast)[0]) - (EMA(Slow)[0] + EMA(mySeries2, Slow)[0]));

		}

		#region Properties
		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Fast", Order=1, GroupName="Parameters")]
		public int Fast
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Slow", Order=2, GroupName="Parameters")]
		public int Slow
		{ get; set; }

		[Browsable(false)]
		[XmlIgnore]
		public Series<double> Leaderplot
		{
			get { return Values[0]; }
		}
		#endregion

	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private Leader[] cacheLeader;
		public Leader Leader(int fast, int slow)
		{
			return Leader(Input, fast, slow);
		}

		public Leader Leader(ISeries<double> input, int fast, int slow)
		{
			if (cacheLeader != null)
				for (int idx = 0; idx < cacheLeader.Length; idx++)
					if (cacheLeader[idx] != null && cacheLeader[idx].Fast == fast && cacheLeader[idx].Slow == slow && cacheLeader[idx].EqualsInput(input))
						return cacheLeader[idx];
			return CacheIndicator<Leader>(new Leader(){ Fast = fast, Slow = slow }, input, ref cacheLeader);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.Leader Leader(int fast, int slow)
		{
			return indicator.Leader(Input, fast, slow);
		}

		public Indicators.Leader Leader(ISeries<double> input , int fast, int slow)
		{
			return indicator.Leader(input, fast, slow);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.Leader Leader(int fast, int slow)
		{
			return indicator.Leader(Input, fast, slow);
		}

		public Indicators.Leader Leader(ISeries<double> input , int fast, int slow)
		{
			return indicator.Leader(input, fast, slow);
		}
	}
}

#endregion
